@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.20.0";
+our $VERSION = "v6.21.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 86 of the 100+ operators in rxjs are implemented in this module.
+Currently 88 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -1151,6 +1151,32 @@ rxjs's throttleTime accepts.
         op_throttle_time(2.1),
     )->subscribe($observer);
 
+=item op_throw_if_empty
+
+L<https://rxjs.dev/api/operators/throwIfEmpty>
+
+    # error: hello
+    rx_timer(1)->pipe(
+        op_ignore_elements(),
+        op_throw_if_empty(sub { "hello" }),
+    )->subscribe($observer);
+
+    # 0, 1, 2, complete
+    rx_interval(0.7)->pipe(
+        op_take(3),
+        op_throw_if_empty(sub { "hello" }),
+    )->subscribe($observer);
+
+=item op_to_array
+
+L<https://rxjs.dev/api/operators/toArray>
+
+    # [0, 1, 2, 3, 4], complete
+    rx_interval(0.7)->pipe(
+        op_take(5),
+        op_to_array(),
+    )->subscribe($observer);
+
 =item op_with_latest_from
 
 L<https://rxjs.dev/api/operators/withLatestFrom>
