@@ -22,11 +22,11 @@ our @EXPORT_OK = qw/
     op_merge_all op_merge_map op_merge_with op_min op_multicast op_on_error_resume_next_with op_pairwise op_pluck
     op_race_with op_reduce op_ref_count op_repeat op_retry op_sample_time op_scan op_share op_skip op_skip_until
     op_skip_while op_start_with op_switch_all op_switch_map op_take op_take_last op_take_until op_take_while op_tap
-    op_throttle_time op_with_latest_from op_zip_with
+    op_throttle_time op_throw_if_empty op_to_array op_with_latest_from op_zip_with
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.20.0";
+our $VERSION = "v6.21.0";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -1902,6 +1902,67 @@ sub op_throttle_time {
     };
 }
 
+sub op_throw_if_empty {
+    my ($error_factory) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $is_empty = 1;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    $is_empty = 0;
+                    $subscriber->{next}->(@_) if defined $subscriber->{next};
+                },
+                complete => sub {
+                    if ($is_empty) {
+                        $subscriber->{error}->($error_factory->()) if defined $subscriber->{error};
+                    } else {
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
+sub op_to_array {
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my @values;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    my ($v) = @_;
+                    push @values, $v;
+                },
+                complete => sub {
+                    $subscriber->{next}->(\@values) if defined $subscriber->{next};
+                    $subscriber->{complete}->() if defined $subscriber->{complete};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_with_latest_from {
     my (@other_observables) = @_;
 
